==> 2.0.3.tar.gz: lib/services/apk_controller.dart <==
import 'package:flutter/services.dart';

import 'package:apk_admin/utils/platform_error_handler.dart';

/// This class controls the behaviors of apps as implemented by the plugin.
class ApkController {
  static const _channel = MethodChannel('com.heda.apk_admin.apk_controller');

  /// This method launches an app by its packageName on device and if it's not installed
  /// it will launch them on play store or the browser depending on if google play store
  /// is installed.
  /// ```
  /// Note that you can set forceAppStore to true if you want to force
  /// the app to open on google play store for example if you want users to rate your app.
  Future<String> launchApp(
    String packageName, {
    bool forceAppStore = false,
  }) async {
    assert(packageName.isNotEmpty, "packageName can not be empty");
    try {
      String launchResult = await _channel.invokeMethod(
        "launchApp",
        {"packageName": packageName, "forceAppStore": forceAppStore},
      );
      return launchResult;
    } on PlatformException catch (e) {
      throwError(e, "opening $packageName");
      return "FailedToOpen";
    }
  }

  /// This method prompts a dialog to the user that asks for his confirmation
  /// to uninstall the specified app.
  Future<void> uninstallApp(String packageName) async {
    assert(packageName.isNotEmpty, "packageName can not be empty");
    try {
      await _channel.invokeMethod(
        "uninstallApp",
        {"packageName": packageName},
      );
    } on PlatformException catch (e) {
      throwError(e, "uninstalling $packageName");
    }
  }
}

==> 2.2.4.tar.gz: lib/services/apk_controller.dart <==
import 'package:flutter/services.dart';

import 'package:apk_admin/utils/platform_error_handler.dart';

/// This class controls the behaviors of apps as implemented by the plugin.
class ApkController {
  static const _channel = MethodChannel('com.heda.apk_admin.apk_controller');

  /// This method launches an app by its packageName on device and if it's not installed
  /// it will launch them on play store or the browser depending on if google play store
  /// is installed.
  /// ```
  /// Note that you can set forceAppStore to true if you want to force
  /// the app to open on google play store for example if you want users to rate your app.
  Future<String?> launchApp(
    String packageName, {
    bool forceAppStore = false,
  }) async {
    assert(packageName.isNotEmpty, "packageName can not be empty");
    try {
      String? launchResult = await _channel.invokeMethod(
        "launchApp",
        {"packageName": packageName, "forceAppStore": forceAppStore},
      );
      return launchResult;
    } on PlatformException catch (e) {
      throwError(e, "opening $packageName");
      return "FailedToOpen";
    }
  }

  /// This method prompts a dialog to the user that asks for his confirmation
  /// to uninstall the specified app.
  Future<void> uninstallApp(String packageName) async {
    assert(packageName.isNotEmpty, "packageName can not be empty");
    try {
      await _channel.invokeMethod(
        "uninstallApp",
        {"packageName": packageName},
      );
    } on PlatformException catch (e) {
      throwError(e, "uninstalling $packageName");
    }
  }
}
